import { DatabaseErrorCode } from '../../constant';
import { superGroupGetMessage as databaseSuperGroupGetMessage, superGroupGetMultipleMessage as databaseSuperGroupGetMultipleMessage, getSuperGroupNormalMsgSeq as databaseGetSuperGroupNormalMsgSeq, superGroupGetNormalMinSeq as databaseSuperGroupGetNormalMinSeq, superGroupUpdateMessageTimeAndStatus as databaseSuperGroupUpdateMessageTimeAndStatus, superGroupUpdateMessage as databaseSuperGroupUpdateMessage, superGroupInsertMessage as databaseSuperGroupInsertMessage, superGroupBatchInsertMessageList as databaseSuperGroupBatchInsertMessageList, superGroupGetMessageListNoTime as databaseSuperGroupGetMessageListNoTime, superGroupGetMessageList as databaseSuperGroupGetMessageList, superGroupSearchAllMessageByContentType as databaseSuperGroupSearchAllMessageByContentType, } from '../../sqls';
import { converSqlExecResult, convertToSnakeCaseObject, formatResponse, } from '../../utils';
import { getInstance } from './instance';
export async function superGroupGetMessage(groupID, messageId) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupGetMessage(db, groupID, messageId);
        if (execResult.length === 0) {
            return formatResponse('', DatabaseErrorCode.ErrorNoRecord, `no message with id ${messageId}`);
        }
        return formatResponse(converSqlExecResult(execResult[0], 'CamelCase', [
            'isRead',
            'isReact',
            'isExternalExtensions',
        ])[0]);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupGetMultipleMessage(messageIdsStr, groupID) {
    try {
        const db = await getInstance();
        const messageIds = JSON.parse(messageIdsStr || '[]');
        const execResult = databaseSuperGroupGetMultipleMessage(db, messageIds, groupID);
        return formatResponse(converSqlExecResult(execResult[0], 'CamelCase', [
            'isRead',
            'isReact',
            'isExternalExtensions',
        ]));
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function getSuperGroupNormalMsgSeq(groupID) {
    try {
        const db = await getInstance();
        const execResult = databaseGetSuperGroupNormalMsgSeq(db, groupID);
        return formatResponse(execResult[0]?.values[0]?.[0]);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupGetNormalMinSeq(groupID) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupGetNormalMinSeq(db, groupID);
        return formatResponse(execResult[0]?.values[0]?.[0]);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupUpdateMessageTimeAndStatus(groupID, clientMsgID, serverMsgID, sendTime, status) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupUpdateMessageTimeAndStatus(db, groupID, clientMsgID, serverMsgID, sendTime, status);
        return formatResponse(execResult);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupUpdateMessage(groupID, clientMsgID, messageStr) {
    try {
        const db = await getInstance();
        const message = convertToSnakeCaseObject(JSON.parse(messageStr));
        const execResult = databaseSuperGroupUpdateMessage(db, groupID, clientMsgID, message);
        return formatResponse(execResult);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupInsertMessage(messageStr, groupID) {
    try {
        const db = await getInstance();
        const message = convertToSnakeCaseObject(JSON.parse(messageStr));
        const execResult = databaseSuperGroupInsertMessage(db, groupID, message);
        return formatResponse(execResult);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupBatchInsertMessageList(messageListStr, groupID) {
    try {
        const db = await getInstance();
        const messageList = JSON.parse(messageListStr).map((v) => convertToSnakeCaseObject(v));
        const execResult = databaseSuperGroupBatchInsertMessageList(db, groupID, messageList);
        return formatResponse(execResult);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupGetMessageListNoTime(groupID, sessionType, count, isReverse = false) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupGetMessageListNoTime(db, groupID, sessionType, count, isReverse);
        return formatResponse(converSqlExecResult(execResult[0], 'CamelCase', [
            'isRead',
            'isReact',
            'isExternalExtensions',
        ]));
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupGetMessageList(groupID, sessionType, count, startTime, isReverse = false) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupGetMessageList(db, groupID, sessionType, count, startTime, isReverse);
        return formatResponse(converSqlExecResult(execResult[0], 'CamelCase', [
            'isRead',
            'isReact',
            'isExternalExtensions',
        ]));
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupUpdateColumnsMessage(clientMsgID, groupID, messageStr) {
    try {
        const db = await getInstance();
        const message = convertToSnakeCaseObject(JSON.parse(messageStr));
        const execResult = databaseSuperGroupUpdateMessage(db, groupID, clientMsgID, message);
        const modifed = db.getRowsModified();
        if (modifed === 0) {
            throw 'superGroupUpdateColumnsMessage no record updated';
        }
        return formatResponse(execResult);
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
export async function superGroupSearchAllMessageByContentType(groupID, contentType) {
    try {
        const db = await getInstance();
        const execResult = databaseSuperGroupSearchAllMessageByContentType(db, groupID, contentType);
        return formatResponse(converSqlExecResult(execResult[0], 'CamelCase', [
            'isRead',
            'isReact',
            'isExternalExtensions',
        ]));
    }
    catch (e) {
        console.error(e);
        return formatResponse(undefined, DatabaseErrorCode.ErrorInit, JSON.stringify(e));
    }
}
